@@ -28,7 +28,7 @@ class AbinitOutput:
         self.compaliance_tensor = None
         self.structure = None
         self.text = None
-
+        self.density = None
         self._parse_output()
 
         # self.elastic_properties = ElasticProperties(
@@ -159,7 +159,7 @@ class AbinitOutput:
         volume *= 1.0e-30  # from Angstrom to meters
         total_mass *= 1.0e-3  # from gram to kg
         density = total_mass / (volume * N_avogadro)
-
+        self.density = density
         print("\nDensity (in kg/m^3 units ): %10.5f" % density)
         print("External Pressure (in GPa units ): %10.5f" % self.pressure)
 
